wot.commands package
====================

Submodules
----------

wot.commands.cells\_by\_gene\_set module
----------------------------------------

.. automodule:: wot.commands.cells_by_gene_set
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.census module
--------------------------

.. automodule:: wot.commands.census
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.convert\_matrix module
-----------------------------------

.. automodule:: wot.commands.convert_matrix
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.force\_layout module
---------------------------------

.. automodule:: wot.commands.force_layout
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.gene\_set\_scores module
-------------------------------------

.. automodule:: wot.commands.gene_set_scores
    :members:
    :undoc-members:
    :show-inheritance:


wot.commands.diff\_exp module
-------------------------------------

.. automodule:: wot.commands.diff_exp
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.optimal\_transport module
--------------------------------------

.. automodule:: wot.commands.optimal_transport
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.optimal\_transport\_validation module
--------------------------------------------------

.. automodule:: wot.commands.optimal_transport_validation
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.trajectory module
------------------------------

.. automodule:: wot.commands.trajectory
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.trajectory\_trends module
--------------------------------------

.. automodule:: wot.commands.trajectory_trends
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.transition\_table module
-------------------------------------

.. automodule:: wot.commands.transition_table
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.util module
------------------------

.. automodule:: wot.commands.util
    :members:
    :undoc-members:
    :show-inheritance:

wot.commands.wot\_server module
-------------------------------

.. automodule:: wot.commands.wot_server
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: wot.commands
    :members:
    :undoc-members:
    :show-inheritance:
